@@ -22,8 +22,8 @@ Here the small things that fit nowhere else and don't deserve their own module.
 """
 
 import os
-import platform
 import sys
+from contextlib import contextmanager
 
 
 def getOS():
@@ -57,6 +57,8 @@ def getLinuxDistribution():
         return None, None
 
     if _linux_distribution_info is None:
+        import platform
+
         # pylint: disable=I0021,deprecated-method,no-member
         try:
             result = platform.dist()[0]
@@ -70,9 +72,9 @@ def getLinuxDistribution():
 
                 for line in getFileContentByLine("/usr/lib/os-release"):
                     if line.startswith("ID="):
-                        result = line[3:]
+                        result = line[3:].strip('"')
                     if line.startswith("VERSION="):
-                        version = line[8:]
+                        version = line[8:].strip('"')
 
             if result is None:
                 from .Execution import check_output
@@ -91,7 +93,7 @@ def getLinuxDistribution():
                 general.sysexit("Error, cannot detect Linux distribution.")
 
         # Change e.g. "11 (Bullseye)"" to "11".
-        if version is not None:
+        if version is not None and version.strip():
             version = version.split()[0]
 
         _linux_distribution_info = result.title(), version
@@ -99,6 +101,15 @@ def getLinuxDistribution():
     return _linux_distribution_info
 
 
+def getWindowsRelease():
+    if getOS() != "Windows":
+        return None
+
+    import platform
+
+    return platform.release()
+
+
 def isDebianBasedLinux():
     # TODO: What is with Mint, maybe others, this list should be expanded potentially.
     dist_name, _dist_version = getLinuxDistribution()
@@ -224,3 +235,25 @@ def getUserName():
     import pwd  # pylint: disable=I0021,import-error
 
     return pwd.getpwuid(os.getuid())[0]
+
+
+@contextmanager
+def withNoDeprecationWarning():
+    import warnings
+
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", category=DeprecationWarning)
+
+        # These do not inherit from DeprecationWarning by some decision we
+        # are not to care about.
+        if "pkg_resources" in sys.modules:
+            try:
+                from pkg_resources import PkgResourcesDeprecationWarning
+            except ImportError:
+                pass
+            else:
+                warnings.filterwarnings(
+                    "ignore", category=PkgResourcesDeprecationWarning
+                )
+
+        yield
